# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from better_auth.models.reset_password200_response import ResetPassword200Response
from better_auth.models.two_factor_enable_post200_response import TwoFactorEnablePost200Response
from better_auth.models.two_factor_enable_post_request import TwoFactorEnablePostRequest
from better_auth.models.two_factor_generate_backup_codes_post200_response import TwoFactorGenerateBackupCodesPost200Response
from better_auth.models.two_factor_generate_backup_codes_post_request import TwoFactorGenerateBackupCodesPostRequest
from better_auth.models.two_factor_get_totp_uri_post200_response import TwoFactorGetTotpUriPost200Response
from better_auth.models.two_factor_get_totp_uri_post_request import TwoFactorGetTotpUriPostRequest
from better_auth.models.two_factor_verify_backup_code_post200_response import TwoFactorVerifyBackupCodePost200Response
from better_auth.models.two_factor_verify_backup_code_post_request import TwoFactorVerifyBackupCodePostRequest
from better_auth.models.two_factor_verify_otp_post200_response import TwoFactorVerifyOtpPost200Response
from better_auth.models.two_factor_verify_otp_post_request import TwoFactorVerifyOtpPostRequest
from better_auth.models.two_factor_verify_totp_post_request import TwoFactorVerifyTotpPostRequest

from better_auth.api_client import ApiClient, RequestSerialized
from better_auth.api_response import ApiResponse
from better_auth.rest import RESTResponseType


class TwoFactorApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def two_factor_disable_post(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResetPassword200Response:
        """two_factor_disable_post

        Use this endpoint to disable two factor authentication.

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_disable_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_disable_post_with_http_info(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResetPassword200Response]:
        """two_factor_disable_post

        Use this endpoint to disable two factor authentication.

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_disable_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_disable_post_without_preload_content(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_disable_post

        Use this endpoint to disable two factor authentication.

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_disable_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_disable_post_serialize(
        self,
        two_factor_get_totp_uri_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_get_totp_uri_post_request is not None:
            _body_params = two_factor_get_totp_uri_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/disable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_enable_post(
        self,
        two_factor_enable_post_request: TwoFactorEnablePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TwoFactorEnablePost200Response:
        """two_factor_enable_post

        Use this endpoint to enable two factor authentication. This will generate a TOTP URI and backup codes. Once the user verifies the TOTP URI, the two factor authentication will be enabled.

        :param two_factor_enable_post_request: (required)
        :type two_factor_enable_post_request: TwoFactorEnablePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_enable_post_serialize(
            two_factor_enable_post_request=two_factor_enable_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorEnablePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_enable_post_with_http_info(
        self,
        two_factor_enable_post_request: TwoFactorEnablePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TwoFactorEnablePost200Response]:
        """two_factor_enable_post

        Use this endpoint to enable two factor authentication. This will generate a TOTP URI and backup codes. Once the user verifies the TOTP URI, the two factor authentication will be enabled.

        :param two_factor_enable_post_request: (required)
        :type two_factor_enable_post_request: TwoFactorEnablePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_enable_post_serialize(
            two_factor_enable_post_request=two_factor_enable_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorEnablePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_enable_post_without_preload_content(
        self,
        two_factor_enable_post_request: TwoFactorEnablePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_enable_post

        Use this endpoint to enable two factor authentication. This will generate a TOTP URI and backup codes. Once the user verifies the TOTP URI, the two factor authentication will be enabled.

        :param two_factor_enable_post_request: (required)
        :type two_factor_enable_post_request: TwoFactorEnablePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_enable_post_serialize(
            two_factor_enable_post_request=two_factor_enable_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorEnablePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_enable_post_serialize(
        self,
        two_factor_enable_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_enable_post_request is not None:
            _body_params = two_factor_enable_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/enable',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_generate_backup_codes_post(
        self,
        two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TwoFactorGenerateBackupCodesPost200Response:
        """two_factor_generate_backup_codes_post

        Generate new backup codes for two-factor authentication

        :param two_factor_generate_backup_codes_post_request: (required)
        :type two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_generate_backup_codes_post_serialize(
            two_factor_generate_backup_codes_post_request=two_factor_generate_backup_codes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGenerateBackupCodesPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_generate_backup_codes_post_with_http_info(
        self,
        two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TwoFactorGenerateBackupCodesPost200Response]:
        """two_factor_generate_backup_codes_post

        Generate new backup codes for two-factor authentication

        :param two_factor_generate_backup_codes_post_request: (required)
        :type two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_generate_backup_codes_post_serialize(
            two_factor_generate_backup_codes_post_request=two_factor_generate_backup_codes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGenerateBackupCodesPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_generate_backup_codes_post_without_preload_content(
        self,
        two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_generate_backup_codes_post

        Generate new backup codes for two-factor authentication

        :param two_factor_generate_backup_codes_post_request: (required)
        :type two_factor_generate_backup_codes_post_request: TwoFactorGenerateBackupCodesPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_generate_backup_codes_post_serialize(
            two_factor_generate_backup_codes_post_request=two_factor_generate_backup_codes_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGenerateBackupCodesPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_generate_backup_codes_post_serialize(
        self,
        two_factor_generate_backup_codes_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_generate_backup_codes_post_request is not None:
            _body_params = two_factor_generate_backup_codes_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/generate-backup-codes',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_get_totp_uri_post(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TwoFactorGetTotpUriPost200Response:
        """two_factor_get_totp_uri_post

        Use this endpoint to get the TOTP URI

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_get_totp_uri_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGetTotpUriPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_get_totp_uri_post_with_http_info(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TwoFactorGetTotpUriPost200Response]:
        """two_factor_get_totp_uri_post

        Use this endpoint to get the TOTP URI

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_get_totp_uri_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGetTotpUriPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_get_totp_uri_post_without_preload_content(
        self,
        two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_get_totp_uri_post

        Use this endpoint to get the TOTP URI

        :param two_factor_get_totp_uri_post_request: (required)
        :type two_factor_get_totp_uri_post_request: TwoFactorGetTotpUriPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_get_totp_uri_post_serialize(
            two_factor_get_totp_uri_post_request=two_factor_get_totp_uri_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorGetTotpUriPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_get_totp_uri_post_serialize(
        self,
        two_factor_get_totp_uri_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_get_totp_uri_post_request is not None:
            _body_params = two_factor_get_totp_uri_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/get-totp-uri',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_send_otp_post(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResetPassword200Response:
        """two_factor_send_otp_post

        Send two factor OTP to the user

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_send_otp_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_send_otp_post_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResetPassword200Response]:
        """two_factor_send_otp_post

        Send two factor OTP to the user

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_send_otp_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_send_otp_post_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_send_otp_post

        Send two factor OTP to the user

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_send_otp_post_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_send_otp_post_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/send-otp',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_verify_backup_code_post(
        self,
        two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TwoFactorVerifyBackupCodePost200Response:
        """two_factor_verify_backup_code_post

        Verify a backup code for two-factor authentication

        :param two_factor_verify_backup_code_post_request: (required)
        :type two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_backup_code_post_serialize(
            two_factor_verify_backup_code_post_request=two_factor_verify_backup_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyBackupCodePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_verify_backup_code_post_with_http_info(
        self,
        two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TwoFactorVerifyBackupCodePost200Response]:
        """two_factor_verify_backup_code_post

        Verify a backup code for two-factor authentication

        :param two_factor_verify_backup_code_post_request: (required)
        :type two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_backup_code_post_serialize(
            two_factor_verify_backup_code_post_request=two_factor_verify_backup_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyBackupCodePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_verify_backup_code_post_without_preload_content(
        self,
        two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_verify_backup_code_post

        Verify a backup code for two-factor authentication

        :param two_factor_verify_backup_code_post_request: (required)
        :type two_factor_verify_backup_code_post_request: TwoFactorVerifyBackupCodePostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_backup_code_post_serialize(
            two_factor_verify_backup_code_post_request=two_factor_verify_backup_code_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyBackupCodePost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_verify_backup_code_post_serialize(
        self,
        two_factor_verify_backup_code_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_verify_backup_code_post_request is not None:
            _body_params = two_factor_verify_backup_code_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/verify-backup-code',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_verify_otp_post(
        self,
        two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TwoFactorVerifyOtpPost200Response:
        """two_factor_verify_otp_post

        Verify two factor OTP

        :param two_factor_verify_otp_post_request: (required)
        :type two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_otp_post_serialize(
            two_factor_verify_otp_post_request=two_factor_verify_otp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyOtpPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_verify_otp_post_with_http_info(
        self,
        two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TwoFactorVerifyOtpPost200Response]:
        """two_factor_verify_otp_post

        Verify two factor OTP

        :param two_factor_verify_otp_post_request: (required)
        :type two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_otp_post_serialize(
            two_factor_verify_otp_post_request=two_factor_verify_otp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyOtpPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_verify_otp_post_without_preload_content(
        self,
        two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_verify_otp_post

        Verify two factor OTP

        :param two_factor_verify_otp_post_request: (required)
        :type two_factor_verify_otp_post_request: TwoFactorVerifyOtpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_otp_post_serialize(
            two_factor_verify_otp_post_request=two_factor_verify_otp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TwoFactorVerifyOtpPost200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_verify_otp_post_serialize(
        self,
        two_factor_verify_otp_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_verify_otp_post_request is not None:
            _body_params = two_factor_verify_otp_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/verify-otp',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def two_factor_verify_totp_post(
        self,
        two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ResetPassword200Response:
        """two_factor_verify_totp_post

        Verify two factor TOTP

        :param two_factor_verify_totp_post_request: (required)
        :type two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_totp_post_serialize(
            two_factor_verify_totp_post_request=two_factor_verify_totp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def two_factor_verify_totp_post_with_http_info(
        self,
        two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ResetPassword200Response]:
        """two_factor_verify_totp_post

        Verify two factor TOTP

        :param two_factor_verify_totp_post_request: (required)
        :type two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_totp_post_serialize(
            two_factor_verify_totp_post_request=two_factor_verify_totp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def two_factor_verify_totp_post_without_preload_content(
        self,
        two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """two_factor_verify_totp_post

        Verify two factor TOTP

        :param two_factor_verify_totp_post_request: (required)
        :type two_factor_verify_totp_post_request: TwoFactorVerifyTotpPostRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._two_factor_verify_totp_post_serialize(
            two_factor_verify_totp_post_request=two_factor_verify_totp_post_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ResetPassword200Response",
            '400': "SocialSignIn400Response",
            '401': "SocialSignIn400Response",
            '403': "SocialSignIn403Response",
            '404': "SocialSignIn403Response",
            '429': "SocialSignIn403Response",
            '500': "SocialSignIn403Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _two_factor_verify_totp_post_serialize(
        self,
        two_factor_verify_totp_post_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if two_factor_verify_totp_post_request is not None:
            _body_params = two_factor_verify_totp_post_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/two-factor/verify-totp',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.stripe_api import StripeApi


class TestStripeApi(unittest.TestCase):
    """StripeApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StripeApi()

    def tearDown(self) -> None:
        pass

    def test_handle_stripe_webhook(self) -> None:
        """Test case for handle_stripe_webhook

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from better_auth.models.account import Account
from better_auth.models.account_info_get200_response import AccountInfoGet200Response
from better_auth.models.account_info_get200_response_user import AccountInfoGet200ResponseUser
from better_auth.models.admin_ban_user_request import AdminBanUserRequest
from better_auth.models.admin_create_user_request import AdminCreateUserRequest
from better_auth.models.admin_has_permission200_response import AdminHasPermission200Response
from better_auth.models.admin_has_permission_request import AdminHasPermissionRequest
from better_auth.models.admin_list_user_sessions200_response import AdminListUserSessions200Response
from better_auth.models.admin_list_user_sessions_request import AdminListUserSessionsRequest
from better_auth.models.admin_list_users200_response import AdminListUsers200Response
from better_auth.models.admin_revoke_user_session_request import AdminRevokeUserSessionRequest
from better_auth.models.admin_set_user_password_request import AdminSetUserPasswordRequest
from better_auth.models.admin_set_user_role_request import AdminSetUserRoleRequest
from better_auth.models.admin_update_user_request import AdminUpdateUserRequest
from better_auth.models.api_key_create_post200_response import ApiKeyCreatePost200Response
from better_auth.models.api_key_create_post_request import ApiKeyCreatePostRequest
from better_auth.models.api_key_delete_post200_response import ApiKeyDeletePost200Response
from better_auth.models.api_key_delete_post_request import ApiKeyDeletePostRequest
from better_auth.models.api_key_get_get200_response import ApiKeyGetGet200Response
from better_auth.models.api_key_list_get200_response_inner import ApiKeyListGet200ResponseInner
from better_auth.models.api_key_update_post_request import ApiKeyUpdatePostRequest
from better_auth.models.apikey import Apikey
from better_auth.models.change_email200_response import ChangeEmail200Response
from better_auth.models.change_email_request import ChangeEmailRequest
from better_auth.models.change_password200_response import ChangePassword200Response
from better_auth.models.change_password_request import ChangePasswordRequest
from better_auth.models.delete_user200_response import DeleteUser200Response
from better_auth.models.delete_user_callback_get200_response import DeleteUserCallbackGet200Response
from better_auth.models.delete_user_request import DeleteUserRequest
from better_auth.models.forget_password200_response import ForgetPassword200Response
from better_auth.models.forget_password_request import ForgetPasswordRequest
from better_auth.models.generate_passkey_registration_options200_response import GeneratePasskeyRegistrationOptions200Response
from better_auth.models.generate_passkey_registration_options200_response_authenticator_selection import GeneratePasskeyRegistrationOptions200ResponseAuthenticatorSelection
from better_auth.models.generate_passkey_registration_options200_response_exclude_credentials_inner import GeneratePasskeyRegistrationOptions200ResponseExcludeCredentialsInner
from better_auth.models.generate_passkey_registration_options200_response_pub_key_cred_params_inner import GeneratePasskeyRegistrationOptions200ResponsePubKeyCredParamsInner
from better_auth.models.generate_passkey_registration_options200_response_rp import GeneratePasskeyRegistrationOptions200ResponseRp
from better_auth.models.generate_passkey_registration_options200_response_user import GeneratePasskeyRegistrationOptions200ResponseUser
from better_auth.models.get_session200_response import GetSession200Response
from better_auth.models.link_social_account200_response import LinkSocialAccount200Response
from better_auth.models.link_social_account_request import LinkSocialAccountRequest
from better_auth.models.link_social_account_request_id_token import LinkSocialAccountRequestIdToken
from better_auth.models.list_user_accounts200_response_inner import ListUserAccounts200ResponseInner
from better_auth.models.ok_get200_response import OkGet200Response
from better_auth.models.one_tap_callback_post200_response import OneTapCallbackPost200Response
from better_auth.models.one_tap_callback_post_request import OneTapCallbackPostRequest
from better_auth.models.passkey import Passkey
from better_auth.models.passkey_delete_passkey_post200_response import PasskeyDeletePasskeyPost200Response
from better_auth.models.passkey_delete_passkey_post_request import PasskeyDeletePasskeyPostRequest
from better_auth.models.passkey_generate_authenticate_options200_response import PasskeyGenerateAuthenticateOptions200Response
from better_auth.models.passkey_update_passkey_post200_response import PasskeyUpdatePasskeyPost200Response
from better_auth.models.passkey_update_passkey_post_request import PasskeyUpdatePasskeyPostRequest
from better_auth.models.passkey_verify_authentication_request import PasskeyVerifyAuthenticationRequest
from better_auth.models.passkey_verify_registration_request import PasskeyVerifyRegistrationRequest
from better_auth.models.refresh_token_post200_response import RefreshTokenPost200Response
from better_auth.models.refresh_token_post_request import RefreshTokenPostRequest
from better_auth.models.reset_password200_response import ResetPassword200Response
from better_auth.models.reset_password_callback200_response import ResetPasswordCallback200Response
from better_auth.models.reset_password_request import ResetPasswordRequest
from better_auth.models.revoke_other_sessions_post200_response import RevokeOtherSessionsPost200Response
from better_auth.models.revoke_session_post200_response import RevokeSessionPost200Response
from better_auth.models.revoke_session_post_request import RevokeSessionPostRequest
from better_auth.models.revoke_sessions_post200_response import RevokeSessionsPost200Response
from better_auth.models.send_verification_email200_response import SendVerificationEmail200Response
from better_auth.models.send_verification_email400_response import SendVerificationEmail400Response
from better_auth.models.send_verification_email_request import SendVerificationEmailRequest
from better_auth.models.session import Session
from better_auth.models.sign_in_email200_response import SignInEmail200Response
from better_auth.models.sign_in_email_request import SignInEmailRequest
from better_auth.models.sign_out200_response import SignOut200Response
from better_auth.models.sign_up_with_email_and_password200_response import SignUpWithEmailAndPassword200Response
from better_auth.models.sign_up_with_email_and_password200_response_user import SignUpWithEmailAndPassword200ResponseUser
from better_auth.models.sign_up_with_email_and_password_request import SignUpWithEmailAndPasswordRequest
from better_auth.models.social_sign_in200_response import SocialSignIn200Response
from better_auth.models.social_sign_in400_response import SocialSignIn400Response
from better_auth.models.social_sign_in403_response import SocialSignIn403Response
from better_auth.models.social_sign_in_request import SocialSignInRequest
from better_auth.models.social_sign_in_request_id_token import SocialSignInRequestIdToken
from better_auth.models.two_factor import TwoFactor
from better_auth.models.two_factor_enable_post200_response import TwoFactorEnablePost200Response
from better_auth.models.two_factor_enable_post_request import TwoFactorEnablePostRequest
from better_auth.models.two_factor_generate_backup_codes_post200_response import TwoFactorGenerateBackupCodesPost200Response
from better_auth.models.two_factor_generate_backup_codes_post_request import TwoFactorGenerateBackupCodesPostRequest
from better_auth.models.two_factor_get_totp_uri_post200_response import TwoFactorGetTotpUriPost200Response
from better_auth.models.two_factor_get_totp_uri_post_request import TwoFactorGetTotpUriPostRequest
from better_auth.models.two_factor_verify_backup_code_post200_response import TwoFactorVerifyBackupCodePost200Response
from better_auth.models.two_factor_verify_backup_code_post200_response_session import TwoFactorVerifyBackupCodePost200ResponseSession
from better_auth.models.two_factor_verify_backup_code_post200_response_user import TwoFactorVerifyBackupCodePost200ResponseUser
from better_auth.models.two_factor_verify_backup_code_post_request import TwoFactorVerifyBackupCodePostRequest
from better_auth.models.two_factor_verify_otp_post200_response import TwoFactorVerifyOtpPost200Response
from better_auth.models.two_factor_verify_otp_post200_response_user import TwoFactorVerifyOtpPost200ResponseUser
from better_auth.models.two_factor_verify_otp_post_request import TwoFactorVerifyOtpPostRequest
from better_auth.models.two_factor_verify_totp_post_request import TwoFactorVerifyTotpPostRequest
from better_auth.models.unlink_account_post_request import UnlinkAccountPostRequest
from better_auth.models.update_user200_response import UpdateUser200Response
from better_auth.models.update_user_request import UpdateUserRequest
from better_auth.models.user import User
from better_auth.models.verification import Verification
from better_auth.models.verify_email_get200_response import VerifyEmailGet200Response




# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.admin_api import AdminApi


class TestAdminApi(unittest.TestCase):
    """AdminApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AdminApi()

    def tearDown(self) -> None:
        pass

    def test_admin_ban_user(self) -> None:
        """Test case for admin_ban_user

        """
        pass

    def test_admin_create_user(self) -> None:
        """Test case for admin_create_user

        """
        pass

    def test_admin_get_user(self) -> None:
        """Test case for admin_get_user

        """
        pass

    def test_admin_has_permission(self) -> None:
        """Test case for admin_has_permission

        """
        pass

    def test_admin_impersonate_user(self) -> None:
        """Test case for admin_impersonate_user

        """
        pass

    def test_admin_list_user_sessions(self) -> None:
        """Test case for admin_list_user_sessions

        """
        pass

    def test_admin_list_users(self) -> None:
        """Test case for admin_list_users

        """
        pass

    def test_admin_remove_user(self) -> None:
        """Test case for admin_remove_user

        """
        pass

    def test_admin_revoke_user_session(self) -> None:
        """Test case for admin_revoke_user_session

        """
        pass

    def test_admin_revoke_user_sessions(self) -> None:
        """Test case for admin_revoke_user_sessions

        """
        pass

    def test_admin_set_user_password(self) -> None:
        """Test case for admin_set_user_password

        """
        pass

    def test_admin_set_user_role(self) -> None:
        """Test case for admin_set_user_role

        """
        pass

    def test_admin_stop_impersonating(self) -> None:
        """Test case for admin_stop_impersonating

        """
        pass

    def test_admin_unban_user(self) -> None:
        """Test case for admin_unban_user

        """
        pass

    def test_admin_update_user(self) -> None:
        """Test case for admin_update_user

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class Apikey(BaseModel):
    """
    Apikey
    """ # noqa: E501
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    start: Optional[StrictStr] = None
    prefix: Optional[StrictStr] = None
    key: Optional[StrictStr] = None
    user_id: Optional[StrictStr] = Field(default=None, alias="userId")
    refill_interval: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="refillInterval")
    refill_amount: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="refillAmount")
    last_refill_at: Optional[datetime] = Field(default=None, alias="lastRefillAt")
    enabled: Optional[StrictBool] = True
    rate_limit_enabled: Optional[StrictBool] = Field(default=True, alias="rateLimitEnabled")
    rate_limit_time_window: Optional[Union[StrictFloat, StrictInt]] = Field(default=86400000, alias="rateLimitTimeWindow")
    rate_limit_max: Optional[Union[StrictFloat, StrictInt]] = Field(default=10, alias="rateLimitMax")
    request_count: Optional[Union[StrictFloat, StrictInt]] = Field(default=0, alias="requestCount")
    remaining: Optional[Union[StrictFloat, StrictInt]] = None
    last_request: Optional[datetime] = Field(default=None, alias="lastRequest")
    expires_at: Optional[datetime] = Field(default=None, alias="expiresAt")
    created_at: Optional[datetime] = Field(default=None, alias="createdAt")
    updated_at: Optional[datetime] = Field(default=None, alias="updatedAt")
    permissions: Optional[StrictStr] = None
    metadata: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["id", "name", "start", "prefix", "key", "userId", "refillInterval", "refillAmount", "lastRefillAt", "enabled", "rateLimitEnabled", "rateLimitTimeWindow", "rateLimitMax", "requestCount", "remaining", "lastRequest", "expiresAt", "createdAt", "updatedAt", "permissions", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Apikey from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "name",
            "start",
            "prefix",
            "key",
            "user_id",
            "refill_interval",
            "refill_amount",
            "last_refill_at",
            "enabled",
            "rate_limit_enabled",
            "rate_limit_time_window",
            "rate_limit_max",
            "request_count",
            "remaining",
            "last_request",
            "expires_at",
            "created_at",
            "updated_at",
            "permissions",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Apikey from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "start": obj.get("start"),
            "prefix": obj.get("prefix"),
            "key": obj.get("key"),
            "userId": obj.get("userId"),
            "refillInterval": obj.get("refillInterval"),
            "refillAmount": obj.get("refillAmount"),
            "lastRefillAt": obj.get("lastRefillAt"),
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else True,
            "rateLimitEnabled": obj.get("rateLimitEnabled") if obj.get("rateLimitEnabled") is not None else True,
            "rateLimitTimeWindow": obj.get("rateLimitTimeWindow") if obj.get("rateLimitTimeWindow") is not None else 86400000,
            "rateLimitMax": obj.get("rateLimitMax") if obj.get("rateLimitMax") is not None else 10,
            "requestCount": obj.get("requestCount") if obj.get("requestCount") is not None else 0,
            "remaining": obj.get("remaining"),
            "lastRequest": obj.get("lastRequest"),
            "expiresAt": obj.get("expiresAt"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "permissions": obj.get("permissions"),
            "metadata": obj.get("metadata")
        })
        return _obj





# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.api.two_factor_api import TwoFactorApi


class TestTwoFactorApi(unittest.TestCase):
    """TwoFactorApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TwoFactorApi()

    def tearDown(self) -> None:
        pass

    def test_two_factor_disable_post(self) -> None:
        """Test case for two_factor_disable_post

        """
        pass

    def test_two_factor_enable_post(self) -> None:
        """Test case for two_factor_enable_post

        """
        pass

    def test_two_factor_generate_backup_codes_post(self) -> None:
        """Test case for two_factor_generate_backup_codes_post

        """
        pass

    def test_two_factor_get_totp_uri_post(self) -> None:
        """Test case for two_factor_get_totp_uri_post

        """
        pass

    def test_two_factor_send_otp_post(self) -> None:
        """Test case for two_factor_send_otp_post

        """
        pass

    def test_two_factor_verify_backup_code_post(self) -> None:
        """Test case for two_factor_verify_backup_code_post

        """
        pass

    def test_two_factor_verify_otp_post(self) -> None:
        """Test case for two_factor_verify_otp_post

        """
        pass

    def test_two_factor_verify_totp_post(self) -> None:
        """Test case for two_factor_verify_totp_post

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Better Auth

    API Reference for your Better Auth Instance

    The version of the OpenAPI document: 1.1.0
    Contact: chasenspace@gmail.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from better_auth.models.two_factor_verify_backup_code_post200_response_user import TwoFactorVerifyBackupCodePost200ResponseUser

class TestTwoFactorVerifyBackupCodePost200ResponseUser(unittest.TestCase):
    """TwoFactorVerifyBackupCodePost200ResponseUser unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TwoFactorVerifyBackupCodePost200ResponseUser:
        """Test TwoFactorVerifyBackupCodePost200ResponseUser
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TwoFactorVerifyBackupCodePost200ResponseUser`
        """
        model = TwoFactorVerifyBackupCodePost200ResponseUser()
        if include_optional:
            return TwoFactorVerifyBackupCodePost200ResponseUser(
                id = '',
                email = '',
                email_verified = True,
                name = '',
                image = '',
                two_factor_enabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return TwoFactorVerifyBackupCodePost200ResponseUser(
                id = '',
                two_factor_enabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testTwoFactorVerifyBackupCodePost200ResponseUser(self):
        """Test TwoFactorVerifyBackupCodePost200ResponseUser"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
